CanonicalMessage

Enum CanonicalMessage 

pub enum CanonicalMessage {
    User {
        id: MessageId,
        content: Vec<ContentBlock>,
        timestamp: ProtocolTimestamp,
    },
    Assistant {
        id: MessageId,
        content: Vec<ContentBlock>,
        stop_reason: StopReason,
        timestamp: ProtocolTimestamp,
    },
    ToolResult {
        id: MessageId,
        tool_call_id: ToolCallId,
        tool_name: String,
        content: Vec<ContentBlock>,
        is_error: bool,
        error: Option<ToolFailure>,
        timestamp: ProtocolTimestamp,
    },
}
A provider-neutral conversation message.

Variants



User

User-authored input.

Fields

id: MessageId

Stable message identifier.

content: Vec<ContentBlock>

User-visible text or images.

timestamp: ProtocolTimestamp

Message creation time.



Assistant

Model-authored output.

Fields

id: MessageId

Stable message identifier.

content: Vec<ContentBlock>

Text, thinking, and tool calls.

stop_reason: StopReason

Normalized completion reason.

timestamp: ProtocolTimestamp

Message completion time.



ToolResult

Result returned for a tool call.

Fields

id: MessageId

Stable message identifier.

tool_call_id: ToolCallId

Tool call receiving this result.

tool_name: String

Registered tool name.

content: Vec<ContentBlock>

Text or image result content.

is_error: bool

Whether execution failed.

error: Option<ToolFailure>

Machine-readable failure details, present only on failure.

timestamp: ProtocolTimestamp

Result completion time.

Implementations

Source

impl CanonicalMessage

pub fn user( id: MessageId, content: Vec<ContentBlock>, timestamp: ProtocolTimestamp, ) -> Result<Self, MessageValidationError>

Creates a validated user message.

Errors

Returns an error when content is empty, too numerous, or contains a block that is invalid for the user role.

pub fn assistant( id: MessageId, content: Vec<ContentBlock>, stop_reason: StopReason, timestamp: ProtocolTimestamp, ) -> Result<Self, MessageValidationError>

Creates a validated assistant message.

Errors

Returns an error when content is empty, too numerous, or contains a block that is invalid for the assistant role.

pub fn tool_result_success( id: MessageId, tool_call_id: ToolCallId, tool_name: impl Into<String>, content: Vec<ContentBlock>, timestamp: ProtocolTimestamp, ) -> Result<Self, MessageValidationError>

Creates a successful tool-result message.

Errors

Returns an error when the tool name or result content is invalid.

pub fn tool_result_failure( id: MessageId, tool_call_id: ToolCallId, tool_name: impl Into<String>, content: Vec<ContentBlock>, error: ToolFailure, timestamp: ProtocolTimestamp, ) -> Result<Self, MessageValidationError>

Creates a failed tool-result message.

Errors

Returns an error when the tool name or result content is invalid.

pub const fn role(&self) -> MessageRole

Returns the message role.