pub enum CommandDecodeError {
UnsupportedVersion {
version: ProtocolVersion,
},
UnsupportedType {
command_type: String,
},
Invalid(String),
}Expand description
Failure while decoding an untrusted command envelope.
Variants
UnsupportedVersion
The protocol major is unsupported and takes precedence over command type.
Fields

version: ProtocolVersionReceived canonical protocol version.
UnsupportedType
The discriminator is canonical but unsupported by this host.
Invalid(String)
The command envelope or known payload is malformed.
Implementations
Sourceimpl CommandDecodeError
impl CommandDecodeError
Sourcepub fn into_protocol_error(self, correlation_id: CorrelationId) -> ProtocolError
pub fn into_protocol_error(self, correlation_id: CorrelationId) -> ProtocolError
Converts a decode failure to a safe protocol error.