pub enum ContentValidationError {
InvalidText,
InvalidMimeType,
InvalidImageData,
InvalidImageReference,
InvalidToolName,
InvalidProviderToolCallId,
ToolArgumentsMustBeObject,
ToolArgumentsOutOfBounds(ProtocolMetadataError),
InvalidExternalContent(ExternalContentError),
}Expand description
Error returned when validating content blocks.
Variants
InvalidText
Text is empty, too large, or contains a null character.
InvalidMimeType
The MIME type is not a supported canonical image type.
InvalidImageData
Inline image data is empty, too large, or not valid standard Base64.
InvalidImageReference
An image reference is empty, too large, or contains controls.
InvalidToolName
The tool name is not canonical.
InvalidProviderToolCallId
The provider tool-call identifier is empty, oversized, or contains controls.
ToolArgumentsMustBeObject
Tool arguments must be a JSON object.
ToolArgumentsOutOfBounds(ProtocolMetadataError)
Tool arguments exceed JSON byte or nesting limits.
InvalidExternalContent(ExternalContentError)
Hosted activity, source, citation, or continuation content is invalid.