pub enum RecordDecodeError {
UnsupportedVersion {
version: ProtocolVersion,
},
UnsupportedType {
record_type: String,
},
Invalid(String),
}Expand description
Failure while decoding an untrusted durable record.
Variants
UnsupportedVersion
The protocol major is unsupported and takes precedence over record type.
Fields

version: ProtocolVersionReceived canonical protocol version.
UnsupportedType
Replay cannot safely understand this required record kind.
Invalid(String)
The known record or envelope is malformed.
Implementations
Sourceimpl RecordDecodeError
impl RecordDecodeError
Sourcepub fn into_protocol_error(self, correlation_id: CorrelationId) -> ProtocolError
pub fn into_protocol_error(self, correlation_id: CorrelationId) -> ProtocolError
Converts a decode failure to a safe protocol error.