pub enum RetryClass {
Never,
Immediate,
AfterBackoff,
}Expand description
Whether and how a caller may retry an operation.
Variants
Never
Retrying the same operation is not safe or useful.
Immediate
The same operation may be retried immediately.
AfterBackoff
The operation may be retried after bounded backoff.