pub enum ToolIdempotency {
Idempotent,
NonIdempotent,
ExternallyReconciled,
}Expand description
Declared retry semantics of a tool execution.
Variants
Idempotent
Repeating the invocation is expected to have the same external effect.
NonIdempotent
Repeating the invocation may duplicate external effects.
ExternallyReconciled
Executor can reconcile an operation by a durable external key.