pub struct ExternalSource { /* private fields */ }Expand description
A normalized external source returned by search or another hosted tool.
Implementations
Sourceimpl ExternalSource
impl ExternalSource
Sourcepub fn new(url: impl Into<String>) -> Result<Self, ExternalContentError>
pub fn new(url: impl Into<String>) -> Result<Self, ExternalContentError>
Creates a source with a bounded HTTP(S) URL.
Errors
Returns an error for non-HTTP(S), empty, oversized, or control-containing URLs.
Sourcepub fn with_title(
self,
title: impl Into<String>,
) -> Result<Self, ExternalContentError>
pub fn with_title( self, title: impl Into<String>, ) -> Result<Self, ExternalContentError>
Adds a bounded, control-free source title.
Errors
Returns an error when the title is empty, oversized, or contains controls.
Sourcepub fn with_snippet(
self,
snippet: impl Into<String>,
) -> Result<Self, ExternalContentError>
pub fn with_snippet( self, snippet: impl Into<String>, ) -> Result<Self, ExternalContentError>
Adds a bounded source snippet.
Errors
Returns an error when the snippet is empty, oversized, or contains a null character.